jan: thuban/Extensions/umn_mapserver __init__.py,1.1,1.2

cvs@intevation.de cvs at intevation.de
Sat Nov 20 22:27:23 CET 2004


Author: jan

Update of /thubanrepository/thuban/Extensions/umn_mapserver
In directory doto:/tmp/cvs-serv9173

Modified Files:
	__init__.py 
Log Message:
Added registry entry and the
importing of the actual umn mapserver management modules.
Included a test for the required Python MapScript.


Index: __init__.py
===================================================================
RCS file: /thubanrepository/thuban/Extensions/umn_mapserver/__init__.py,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- __init__.py	10 Jun 2004 10:36:24 -0000	1.1
+++ __init__.py	20 Nov 2004 21:27:21 -0000	1.2
@@ -1,7 +1,33 @@
 # -*- coding:latin1 -*-
 # Copyright (C) 2004 by Intevation GmbH
 # Authors:
 # Jan Schüngel <jschuengel at intevation.de>
 #
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with Thuban for details.
+
+# first try out whether we can import the required module
+# of UMN MapServer MapScript.
+ok = True
+try:
+    import mapscript
+except:
+    print "Problems with UMN MapServer MapScript (not installed?)"
+    ok = False
+
+if ok:
+    import mf_import
+    import mf_export
+    import mf_handle
+
+    from Thuban.UI.extensionregistry import ExtensionDesc, ext_registry
+    from Thuban import _
+
+    ext_registry.add(ExtensionDesc(
+        name = 'UMN MapServer Management',
+        version = '1.0.0',
+        authors= [ 'Jan Schüngel' ],
+        copyright = '2004 Intevation GmbH',
+        desc = _("Provide management methods for UMN MapServer\n" \
+                 ".map-files. These can be created/imported/modified.")))
@@ -1,7 +1,33 @@
 # Copyright (C) 2004 by Intevation GmbH
 # Authors:
-# Jan Schüngel <jschuengel at intevation.de>
+# Jan Schüngel <jschuengel at intevation.de> (2004)
+# Jan-Oliver Wagner <jan at intevation.de> (2004)
 #
 # This program is free software under the GPL (>=v2)





More information about the Thuban-devel mailing list

This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)